==> jc-1.4.0.tar.gz: java/util/Collections__24SingletonSet.h <==
// final class java.util.Collections$SingletonSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 2fe1f02269f56fe8 java_util_Collections__24SingletonSet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_Collections__24SingletonSet_H_
#define _JC_java_util_Collections__24SingletonSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SingletonSet$sub_refs	_jc_java_util_Collections__24SingletonSet$sub_refs;
typedef struct _jc_java_util_Collections__24SingletonSet$sub_nonrefs	_jc_java_util_Collections__24SingletonSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SingletonSet$refs	_jc_java_util_Collections__24SingletonSet$refs;
typedef struct _jc_java_util_Collections__24SingletonSet$nonrefs	_jc_java_util_Collections__24SingletonSet$nonrefs;
typedef struct _jc_java_util_Collections__24SingletonSet$object	_jc_java_util_Collections__24SingletonSet$object;

typedef struct _jc_java_util_Collections__24SingletonSet$fields_struct	_jc_java_util_Collections__24SingletonSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SingletonSet$vmethods	_jc_java_util_Collections__24SingletonSet$vmethods;
typedef const struct _jc_java_util_Collections__24SingletonSet$vtable	_jc_java_util_Collections__24SingletonSet$vtable;
typedef const struct _jc_java_util_Collections__24SingletonSet$vtype	_jc_java_util_Collections__24SingletonSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SingletonSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SingletonSet$fields_struct _jc_java_util_Collections__24SingletonSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SingletonSet$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24SingletonSet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_util_Collections__24SingletonSet$method$containsAll$84ec995bc785c34c(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_object *);
extern jint _jc_java_util_Collections__24SingletonSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
extern struct _jc_object *_jc_java_util_Collections__24SingletonSet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
extern jint _jc_java_util_Collections__24SingletonSet$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
extern _jc_object_array *_jc_java_util_Collections__24SingletonSet$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24SingletonSet$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$containsAll$84ec995bc785c34c;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24SingletonSet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*containsAll$84ec995bc785c34c)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *);
};

// Vtable
struct _jc_java_util_Collections__24SingletonSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_Collections__24SingletonSet$vmethods	java_util_Collections__24SingletonSet;
};

// Vtype
struct _jc_java_util_Collections__24SingletonSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SingletonSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonSet$sub_refs {
	struct _jc_java_lang_Object$object	*element;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SingletonSet$refs {
    _jc_java_util_Collections__24SingletonSet$sub_refs	java_util_Collections__24SingletonSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SingletonSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_Collections__24SingletonSet$sub_nonrefs	java_util_Collections__24SingletonSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SingletonSet$object {
	_jc_java_util_Collections__24SingletonSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SingletonSet$vtype	*vtype;
	_jc_java_util_Collections__24SingletonSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SingletonSet$vtype _jc_java_util_Collections__24SingletonSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SingletonSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SingletonSet$class_object;

#endif	/* _JC_java_util_Collections__24SingletonSet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SingletonSet.h <==
// final class java.util.Collections$SingletonSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 2fe1f02269f56fe8 java_util_Collections__24SingletonSet

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_Collections__24SingletonSet_H_
#define _JC_java_util_Collections__24SingletonSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SingletonSet$sub_refs	_jc_java_util_Collections__24SingletonSet$sub_refs;
typedef struct _jc_java_util_Collections__24SingletonSet$sub_nonrefs	_jc_java_util_Collections__24SingletonSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SingletonSet$refs	_jc_java_util_Collections__24SingletonSet$refs;
typedef struct _jc_java_util_Collections__24SingletonSet$nonrefs	_jc_java_util_Collections__24SingletonSet$nonrefs;
typedef struct _jc_java_util_Collections__24SingletonSet$object	_jc_java_util_Collections__24SingletonSet$object;

typedef struct _jc_java_util_Collections__24SingletonSet$fields_struct	_jc_java_util_Collections__24SingletonSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SingletonSet$vmethods	_jc_java_util_Collections__24SingletonSet$vmethods;
typedef const struct _jc_java_util_Collections__24SingletonSet$vtable	_jc_java_util_Collections__24SingletonSet$vtable;
typedef const struct _jc_java_util_Collections__24SingletonSet$vtype	_jc_java_util_Collections__24SingletonSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SingletonSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SingletonSet$fields_struct _jc_java_util_Collections__24SingletonSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SingletonSet$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24SingletonSet$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_Collections__24SingletonSet$method$containsAll$84ec995bc785c34c(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SingletonSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SingletonSet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SingletonSet$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_util_Collections__24SingletonSet$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_Collections__24SingletonSet$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$containsAll$84ec995bc785c34c;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$toArray$408321282fd84959;
extern _jc_method _jc_java_util_Collections__24SingletonSet$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_Collections__24SingletonSet$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*containsAll$84ec995bc785c34c)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_Collections__24SingletonSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SingletonSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_Collections__24SingletonSet$vmethods	java_util_Collections__24SingletonSet;
};

// Vtype
struct _jc_java_util_Collections__24SingletonSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SingletonSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonSet$sub_refs {
	struct _jc_java_lang_Object$object	*element;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SingletonSet$refs {
    _jc_java_util_Collections__24SingletonSet$sub_refs	java_util_Collections__24SingletonSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SingletonSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_Collections__24SingletonSet$sub_nonrefs	java_util_Collections__24SingletonSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SingletonSet$object {
	_jc_java_util_Collections__24SingletonSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SingletonSet$vtype	*vtype;
	_jc_java_util_Collections__24SingletonSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SingletonSet$vtype _jc_java_util_Collections__24SingletonSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SingletonSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SingletonSet$class_object;

#endif	/* _JC_java_util_Collections__24SingletonSet_H_ */
